@@ -154,9 +154,14 @@ class OutOfBandResponder:
         self,
         wrapped_app: WsgiApplication,
         port=0,
-        cleanup_interval_seconds=CLEANUP_INTERVAL_SECONDS,
-        item_expiry_seconds=ITEM_EXPIRY_SECONDS,
+        cleanup_interval_seconds: Optional[float] = None,
+        item_expiry_seconds: Optional[float] = None,
     ):
+        if cleanup_interval_seconds is None:
+            cleanup_interval_seconds = CLEANUP_INTERVAL_SECONDS
+        if item_expiry_seconds is None:
+            item_expiry_seconds = ITEM_EXPIRY_SECONDS
+
         self._job_transfer = KeyedTransfer(
             cleanup_interval_seconds, item_expiry_seconds
         )
